TokenTree

Struct TokenTree 

pub struct TokenTree<'s> {
    pub span: Option<Span>,
    pub prefix_comments: Vec<&'s str>,
    pub value: TokenValue<'s>,
    pub suffix_comment: Option<&'s str>,
}
A tree of tokens, representing the structure of the Eon source code, including comments.

This is actually something between a Concrete Syntax Tree (CST) and an Abstract Syntax Tree (AST), in that it preserves comments, but discards whitespace and some optional tokens (like commas after list items), though those can be inferred from the Span of the tokens, together with the original Eon file

Fields

span: Option<Span>

The span of this token tree in the source code, if known.

prefix_comments: Vec<&'s str>

Comments on proceeding lines.

// Like this
// and this.
42
value: TokenValue<'s>

The actual value.

suffix_comment: Option<&'s str>

Comment after the value on the same line.

value // Like this.

Implementations

Source

impl TokenTree<'_>

pub fn format(&self, options: &FormatOptions) -> String

Format as an Eon string.

Source

impl<'s> TokenTree<'s>

pub fn parse_str(source: &'s str) -> Result<Self>

Parse a full Eon file.